char2int: char2int function
Description
This function reads input list objects and maps unique numbers to each member in the network/ genesets.
Usage
char2int(net.list, gs.list.1, gs.list.2 = NULL)
Arguments
net.list
the global network object, pre-created using import.net gs.list.1
AGS or FGS object that lists members of each individual AGS/FGS, pre-created using samples2ags gs.list.2
FGS or AGS object that lists members of each individual FGS/AGS, pre-created using samples2ags