This function reads input list objects and maps unique numbers to each member in the network/ genesets.
char2int.fast(net.list, gs.list.1, gs.list.2 = NULL, Parallelize = 1)the global network object, pre-created using import.net
AGS or FGS object that lists members of each individual AGS/FGS, pre-created using samples2ags
FGS or AGS object that lists members of each individual FGS/AGS, pre-created using samples2ags
The number of CPU cores to be used for the step "Counting actual network links" (the other steps are sufficiently fast). The option is not supported on Windows.