Learn R Programming

NEArender (version 1.4)

connectivity: Node degree distribution and network scale-freeness

Description

Auxiliary function to estimate how much a certain network satisfy the property of scale-freeness.

Usage

connectivity(NET, Lowercase = 1, col.1 = 1, col.2 = 2, echo = 1, main = "Connectivity plot")

Arguments

NET
Either a text network file or an R list imported with import.net
Lowercase
Render gene/protein IDs lower-case.
col.1
Number of the column in the input file that corresponds to node 1 (gene/protein ID).
col.2
Number of the column in the input file that corresponds to node 2 (gene/protein ID).
echo
if execution progress should be reported.
main
The plot title.

See Also

topology2nd, benchmark

Examples

Run this code
data(net.kegg)
net <- net.kegg
connectivity(NET=net, main="Scale-free property of KEGG network")

Run the code above in your browser using DataLab