col.mask
To include only columns with IDs that contain the specified mask. This parameter is aware of regular expression syntax, i.e. uses grep(..., fixed = FALSE).
namesFromColumn
Number of the column (if any) that contains the gene/protein names. Note that it is only necessary if the latter are NOT the unique rownames of the matrix. This could be sometimes useful for processing redundant gene profiles with one-to-many mapping etc. Otherwise (i.e. the default), rownames shall contain gene IDs.