Learn R Programming

NEArender (version 1.4)

net.kegg: A more compact alternative global network for the network enrichment analysis

Description

A more compact alternative global network for the network enrichment analysis

Usage

data(net.kegg)

Arguments

Format

A list, see import.net

Examples

Run this code
head(net.kegg)

Run the code above in your browser using DataLab