powered by
Auxiliary function to estimate how non-random are associations of node degrees in network edges.
topology2nd(NET, Lowercase = 1, col.1 = 1, col.2 = 2, echo = 1, main = "Higher order topology")
Either a text network file or an R list imported with import.net
import.net
Render gene/protein IDs lower-case.
Number of the column in the input file that corresponds to node 1 (gene/protein ID).
Number of the column in the input file that corresponds to node 2 (gene/protein ID).
if execution progress should be reported.
The plot title.
connectivity, benchmark
connectivity
benchmark
# NOT RUN { file <- system.file("extdata", "Connectivity.FC1_full", package = "NEArender") # } # NOT RUN { topology2nd(NET=file) # }
Run the code above in your browser using DataLab